@@ -24,10 +24,10 @@ app.service('FlowGraphSelection', function($rootScope, FlowGraphFolding, Taggabl
     */
     const svc = this;
 
-    // contains all selected nodes, including duplicated objects node if they are in multiple flow-zones
-    // however, when an item is selected multiple times, only one instance of it has the field 'selected' set to true
-    // so calling FlowGraphSelection.getSelectedNodes will only get one instance of each real item
-    // it may however not be the one from its source flow-zone.
+    // contains all selected nodes, including all duplicated objects node if they are in multiple flow-zones
+    // however only one node of it has the field 'selected' set to true (later referred as flag-selected)
+    // => calling FlowGraphSelection.getSelectedNodes will only get flag-selected nodes, so only one instance of each real item
+    // => when applicable, the flag-selected node is the last selected by the user, so that reading its zone gives the zone from which it was selected (not always its source flow-zone)
     let selectedItems = [];
 
     function _isSelected(item) {
@@ -66,13 +66,17 @@ app.service('FlowGraphSelection', function($rootScope, FlowGraphFolding, Taggabl
     function _addToSelection(items) {
 
         items = items.filter(it => !_isSelected(it));
+        // For objects used in multiple zones, we mark as flag-selected the nodes just clicked
+        // but in case of lasso-selection, it's possible multiple nodes for the same real object have been captured.
+        // In this case, we flag-select one node. which one is semi-random but stable (depends on DOM order)
+        _.uniqBy(items, it => it.realId).forEach(it => it.selected = true);
+
         var realIdsSelected = items.map(it => it.realId);
         selectedItems = selectedItems.filter(it => !it.realId || !realIdsSelected.includes(it.realId));
         if (!items.length) {
             return;
         }
 
-        const addedNodes = [];
         const selector = items.map(it => _isZoned(it) ? `svg [data-node-id="${it.realId}"]` : _isZone(it) ? `svg [id="cluster_${it.id}"]` : `svg [data-id="${it.id}"]`).join(', ');
         d3.selectAll(selector).each(function() {
             const type = this.getAttribute('data-type');
@@ -81,15 +85,9 @@ app.service('FlowGraphSelection', function($rootScope, FlowGraphFolding, Taggabl
                 key = key.replace("cluster_", "");
                 FlowGraphHighlighting.highlightZoneCluster(this)
             }
-            const node = FlowGraph.node(key);
-            node.selected = false; // we need a single node per realId marked as .selected => step 1: cleanup all nodes
-            addedNodes.push(node);
-            selectedItems.push(node);
+            selectedItems.push(FlowGraph.node(key));
         }).classed("selected", true);
 
-        // we need a single node per realId marked as .selected => step 2: add one selected per realId
-        _.uniqBy(addedNodes, it => it.realId).forEach(it => it.selected = true);
-
         if (selectedItems.length) {
             $('#flow-graph').addClass('has-selection');
         }
