@@ -343,69 +343,72 @@
 
         $scope.updateColumnsSelection = function() {
             updateUnionSchema();
+            if(!$scope.params) {
+                return;
+            }
 
             // clear the columnsMatch value in each input if the mode is not REMAP
             if ($scope.params.mode != 'REMAP') {
                 $scope.params.virtualInputs.forEach(vi => { delete vi.columnsMatch; });
             }
 
+            let selectedColumnsNames = [];
+
             if ($scope.params.mode == 'CUSTOM') {
-                return;
+                selectedColumnsNames = $scope.params.selectedColumns;
             } else if ($scope.params.mode == 'UNION') {
-                $scope.params.selectedColumns = $scope.unionSchema.map(function(col) {
+                selectedColumnsNames = $scope.unionSchema.map(function(col) {
                     return col.name;
                 });
-            } else {
-                var selectedColumnsNames = [];
-                if ($scope.params.mode == 'FROM_DATASET') {
+            } else if ($scope.params.mode == 'FROM_DATASET') {
+                $scope.params.copySchemaFromDatasetWithName = $scope.params.copySchemaFromDatasetWithName || $scope.recipe.inputs.main.items[0].ref;
+                let selectedColumns = $scope.getColumns($scope.params.copySchemaFromDatasetWithName);
+                selectedColumnsNames = selectedColumns.map(col => col.name);
+            } else if ($scope.params.mode == 'FROM_INDEX') {
+                if ($scope.params.selectedColumnsIndexes && $scope.params.selectedColumns
+                    && $scope.params.selectedColumnsIndexes.length == $scope.params.selectedColumns.length) {
+                    selectedColumnsNames = $scope.params.selectedColumns;
+                } else {
                     $scope.params.copySchemaFromDatasetWithName = $scope.params.copySchemaFromDatasetWithName || $scope.recipe.inputs.main.items[0].ref;
                     let selectedColumns = $scope.getColumns($scope.params.copySchemaFromDatasetWithName);
                     selectedColumnsNames = selectedColumns.map(col => col.name);
-                } else if ($scope.params.mode == 'FROM_INDEX') {
-                    if ($scope.params.selectedColumnsIndexes && $scope.params.selectedColumns
-                        && $scope.params.selectedColumnsIndexes.length == $scope.params.selectedColumns.length) {
-                        selectedColumnsNames = $scope.params.selectedColumns;
-                    } else {
-                        $scope.params.copySchemaFromDatasetWithName = $scope.params.copySchemaFromDatasetWithName || $scope.recipe.inputs.main.items[0].ref;
-                        let selectedColumns = $scope.getColumns($scope.params.copySchemaFromDatasetWithName);
-                        selectedColumnsNames = selectedColumns.map(col => col.name);
-                        $scope.useAsReference($scope.params.copySchemaFromDatasetWithName);
-                    }
-                    updateSelectableColumns();
-                    syncSelectors();
-                    let maxColNb = 0;
-                    for (let i = 0; i < $scope.recipe.inputs.main.items.length; i++) {
-                        maxColNb = Math.max(maxColNb, $scope.getColumns($scope.recipe.inputs.main.items[i].ref).length);
-                    }
-                    $scope.selectedColumns.forEach((col, idx) => { if (idx >= maxColNb) { col.selected = false; } });
-                } else if ($scope.params.mode == 'REMAP') {
-                    $scope.params.copySchemaFromDatasetWithName = $scope.params.copySchemaFromDatasetWithName || $scope.recipe.inputs.main.items[0].ref;
-                    $scope.columnsSelection.possibleColumnNames = $scope.columnsSelection.possibleColumnNames || []
-                    let selectedColumns = $scope.getColumns($scope.params.copySchemaFromDatasetWithName);
-                    if ($scope.params.selectedColumns) {
-                        selectedColumnsNames = $scope.params.selectedColumns;
-                        $scope.unionSchema.forEach(col => { col.selected = false })
-                    } else {
-                        selectedColumnsNames = selectedColumns.map(col => col.name);
-                    }
-                    buildInitialColumnsMatch(selectedColumnsNames);
-                } else if ($scope.params.mode == 'INTERSECT') {
-                    let allInputs = RecipesUtils.getFlatInputsList($scope.recipe);
-                    let selectedColumns = $scope.getColumns(allInputs[0].ref);
+                    $scope.useAsReference($scope.params.copySchemaFromDatasetWithName);
+                }
+                updateSelectableColumns();
+                syncSelectors();
+                let maxColNb = 0;
+                for (let i = 0; i < $scope.recipe.inputs.main.items.length; i++) {
+                    maxColNb = Math.max(maxColNb, $scope.getColumns($scope.recipe.inputs.main.items[i].ref).length);
+                }
+                $scope.selectedColumns.forEach((col, idx) => { if (idx >= maxColNb) { col.selected = false; } });
+            } else if ($scope.params.mode == 'REMAP') {
+                $scope.params.copySchemaFromDatasetWithName = $scope.params.copySchemaFromDatasetWithName || $scope.recipe.inputs.main.items[0].ref;
+                $scope.columnsSelection.possibleColumnNames = $scope.columnsSelection.possibleColumnNames || []
+                let selectedColumns = $scope.getColumns($scope.params.copySchemaFromDatasetWithName);
+                if ($scope.params.selectedColumns) {
+                    selectedColumnsNames = $scope.params.selectedColumns;
+                    $scope.unionSchema.forEach(col => { col.selected = false })
+                } else {
                     selectedColumnsNames = selectedColumns.map(col => col.name);
-                    for (var i = 1; i < allInputs.length; i++) {
-                        var columnNames = $scope.getColumns(allInputs[i].ref).map(function(col){return col.name;});
-                        for (var c = selectedColumnsNames.length - 1; c >= 0; c--) {
-                            if (columnNames.indexOf(selectedColumnsNames[c]) < 0) {
-                                selectedColumnsNames.splice(c, 1);
-                            }
+                }
+                buildInitialColumnsMatch(selectedColumnsNames);
+            } else if ($scope.params.mode == 'INTERSECT') {
+                let allInputs = RecipesUtils.getFlatInputsList($scope.recipe);
+                let selectedColumns = $scope.getColumns(allInputs[0].ref);
+                selectedColumnsNames = selectedColumns.map(col => col.name);
+                for (var i = 1; i < allInputs.length; i++) {
+                    var columnNames = $scope.getColumns(allInputs[i].ref).map(function(col){return col.name;});
+                    for (var c = selectedColumnsNames.length - 1; c >= 0; c--) {
+                        if (columnNames.indexOf(selectedColumnsNames[c]) < 0) {
+                            selectedColumnsNames.splice(c, 1);
                         }
                     }
                 }
-                $scope.params.selectedColumns = selectedColumnsNames;
             }
+
+            $scope.params.selectedColumns = selectedColumnsNames;
             updateSelectedColumns();
-            $scope.updateGlobalSelectionStatus(); // keep "select all" checkbox synchronised
+            $scope.updateGlobalSelectionStatus(); // keep "select all" checkbox synchronized
         };
 
         $scope.isColumnsMatch = function(referenceColumns, selectedColumns) {
