@@ -4,7 +4,7 @@
     const app = angular.module('dataiku.charts');
 
     // (!) This directive previously was in static/dataiku/js/simple_report/config_ui.js
-    app.directive('scatterDetailZone', function($parse, ChartLabels, ChartUADimension) {
+    app.directive('scatterDetailZone', function($parse, ChartLabels, ChartUADimension, Ng2MenuOrchestratorService) {
         return {
             templateUrl: '/static/dataiku/js/simple_report/directives/drag-drop/drop-zones/scatter-detail-zone/scatter-detail-zone.directive.html',
             scope: true,
@@ -14,6 +14,10 @@
                 $scope.acceptCallback = $parse(attrs.acceptCallback)($scope);
                 $scope.ChartLabels = ChartLabels;
                 $scope.dateModes = ChartUADimension.getDateModes().map(({ value, label }) => ([value, label]));
+
+                $scope.openMatMenu = function(menuIdx, event) {
+                    Ng2MenuOrchestratorService.triggerMenuOpen($scope.chartDefKey, menuIdx, event);
+                };
             }
         };
     });
