@@ -5,6 +5,7 @@
     /** @typedef {import("../types").GeneratedSources.DimensionDef} DimensionDef */
     /** @typedef {import("../types").GeneratedSources.MeasureDef} MeasureDef */
     /** @typedef {import("../types").GeneratedSources.ChartFilter} ChartFilter */
+    /** @typedef {import("../types").GeneratedSources.ChartDef} ChartDef */
     /** @typedef {import("../../../../../../../../server//src/frontend/node_modules/ag-grid-enterprise/").GridOptions} GridOptions */
     /** @typedef {import("../../../../../../../../server//src/frontend/node_modules/ag-grid-enterprise/").GridApi} GridApi */
 
@@ -278,6 +279,30 @@
             setGridApi: function(gridApi, frameIndex = 0, facetIndex = 0) {
                 chartSpecs.insert(frameIndex, facetIndex, 'gridApi', gridApi);
             },
+            /**
+             *
+             * @param {{ [hierarchyName: string]: string[]}} hierarchyMissingColumns
+             * @param {number} frameIndex
+             * @param {number} facetIndex
+             */
+            setHierarchyMissingColumns: function(hierarchyMissingColumns, frameIndex = 0, facetIndex = 0) {
+                chartSpecs.insert(frameIndex, facetIndex, 'hierarchyMissingColumns', hierarchyMissingColumns);
+            },
+            /**
+             *
+             * @param {number} frameIndex
+             * @param {number} facetIndex
+             * @returns {{ [hierarchyName: string]: string[]}}
+             */
+            getHierarchyMissingColumns: function(frameIndex = 0, facetIndex = 0) {
+                let hierarchyMissingColumns = chartSpecs.get(frameIndex, facetIndex, 'hierarchyMissingColumns');
+
+                if (hierarchyMissingColumns === undefined) {
+                    hierarchyMissingColumns = chartSpecs.insert(frameIndex, facetIndex, 'hierarchyMissingColumns', {});
+                }
+
+                return hierarchyMissingColumns;
+            },
             /**
              * Returns server request options
              * @param {number} frameIndex
@@ -336,6 +361,46 @@
                 const axisSpecs = this.getAllAxisSpecs(axisId);
                 const uniqueNumParamsMode = Array.from(new Set(axisSpecs.map(spec => spec && spec.dimension && spec.dimension.type && spec.dimension.numParams && spec.dimension.numParams.mode)));
                 return uniqueNumParamsMode.length === 1 ? uniqueNumParamsMode[0] : null;
+            },
+
+            /**
+             * Stores the measures' & dimensions' Ids into the ChartStore
+             * @param {ChartDef} chartDef
+             */
+            updateChartStoreMeasureIDsAndDimensionIDs(chartDef) {
+                this.purgeMeasureIds();
+                this.purgeDimensionIds();
+                chartDef.genericMeasures.forEach((measure, i) => this.setMeasureId(measure, this.getMeasureUniqueId(measure, i)));
+                chartDef.yDimension.forEach((yDim, i) => this.setDimensionId(yDim, this.getDimensionUniqueId(yDim, i, 'yDimension')));
+                chartDef.xDimension.forEach((xDim, i) => this.setDimensionId(xDim, this.getDimensionUniqueId(xDim, i, 'xDimension')));
+
+                if (chartDef.xHierarchyDimension && chartDef.xHierarchyDimension.length) {
+                    chartDef.xHierarchyDimension[0].dimensions.forEach((dim, i) => this.setDimensionId(dim, this.getDimensionUniqueId(dim, i, 'xHierarchyDimension')));
+                }
+                if (chartDef.yHierarchyDimension && chartDef.yHierarchyDimension.length) {
+                    chartDef.yHierarchyDimension[0].dimensions.forEach((dim, i) => this.setDimensionId(dim, this.getDimensionUniqueId(dim, i, 'yHierarchyDimension')));
+                }
+            },
+
+            /**
+             * Generates a unique ID for a dimensions
+             * @param {DimensionDef} dimension
+             * @param {number} index
+             * @param {string} type
+             */
+            getDimensionUniqueId(dimension, index, type) {
+                // Replaces points by underscore because dimension ids are used to build column ids with AGGrid which can't have dots.
+                return (`${type}_${index}_${dimension.column}`).replace('.', '_');
+            },
+
+            /**
+             * Generates a unique ID for a dimensions
+             * @param {MeasureDef} measure
+             * @param {number} index
+             */
+            getMeasureUniqueId(measure, index) {
+                // Replaces points by underscore because measure ids are used to build column ids with AGGrid which can't have dots.
+                return (`measure_${index}_${measure.column}`).replace('.', '_');
             }
         };
     }
