@@ -28,6 +28,8 @@ app.controller("WebAppsCommonController", function($scope, $state, $rootScope, $
             $controller("DashWebAppController", {$scope});
         } else if (baseType == 'SHINY') {
             $controller("ShinyWebAppController", {$scope});
+        } else if (baseType == 'STREAMLIT') {
+            $controller("StreamlitWebAppController", {$scope});
         } else if (baseType == 'CODE_STUDIO_AS_WEBAPP') {
             $controller("CodeStudioWebAppController", {$scope});
         } else {
@@ -85,7 +87,7 @@ app.controller("WebAppsCommonController", function($scope, $state, $rootScope, $
     };
 
     $scope.backendEnabled = function () {
-        return $scope.app && ($scope.app.params.backendEnabled || ['BOKEH', 'DASH', 'SHINY', 'CODE_STUDIO_AS_WEBAPP'].indexOf($scope.app.type) >= 0);
+        return $scope.app && ($scope.app.params.backendEnabled || ['BOKEH', 'DASH', 'SHINY', 'STREAMLIT', 'CODE_STUDIO_AS_WEBAPP'].includes($scope.app.type));
     };
 
     $scope.setBackendLogs = function(data) {
@@ -123,7 +125,7 @@ app.controller("WebAppsCommonController", function($scope, $state, $rootScope, $
         }
     };
     
-    const editableTypes = ['BOKEH', 'DASH', 'SHINY', 'STANDARD'];
+    const editableTypes = ['BOKEH', 'DASH', 'SHINY', 'STREAMLIT', 'STANDARD'];
     $scope.isEditableWebAppType = function(webappType) {
         return editableTypes.includes(webappType);
     };
@@ -326,163 +328,8 @@ app.controller("WebAppsListController", function($scope, $controller, $statePara
     }
 });
 
-
-
-/**
- * Temporary: it's in this file by laziness / quick fix for 13.4.0 -- Should be moved to a proper file
- */
-app.controller("ChatUIsListController", function($scope, $controller, $stateParams, DataikuAPI, CreateModalFromTemplate, $state, $q, TopNav, Fn, $filter, Dialogs, WT1, PluginsService, StateUtils) {
-
-    $controller('_TaggableObjectsListPageCommon', {$scope: $scope});
-    $controller("WebAppsCommonController", {$scope: $scope});
-
-    const answersPluginId = "document-question-answering";
-    const answersComponentId = "webapp_document-question-answering_document-intelligence-explorer"
-    const agentConnectPluginId = "agent-connect";
-    const agentConnectComponentId = "webapp_agent-connect_portal";
-    const agentHubPluginId = "agent-hub";
-    const agentHubComponentId = "webapp_agent-hub_agent-hub";
-
-    $scope.agentConnectComponentId = agentConnectComponentId;
-
-    $scope.listHeads = function(projectKey, tagsFilter) {
-        const deferred = $q.defer();
-        deferred.promise.success = function(callback) {
-            deferred.promise.then( (resp) => {return callback(resp.data, resp.status, resp.headers, resp.config, resp.statusText, resp.xhrStatus)});
-            return deferred.promise;
-        };
-        deferred.promise.error = function(callback) {
-            deferred.promise.then(null, resp => callback(resp.data, resp.status, resp.headers, resp.config, resp.statusText, resp.xhrStatus));
-            return deferred.promise;
-        };
-        DataikuAPI.webapps.listHeads(projectKey, tagsFilter).success(function(data) {
-            data.items = data.items.filter(w => [answersComponentId, agentConnectComponentId, agentHubComponentId].includes(w.type)
-                && (!w.config || w.config.isInstalled || w.config.isInstalled == null));
-            deferred.resolve({"data": data})
-        }).error(setErrorInScope.bind($scope));
-        return deferred.promise;
-    }
-
-    function isPluginInstalled(pluginId) {
-        return PluginsService.checkInstalledStatus(pluginId).catch(setErrorInScope.bind($scope));
-    }
-
-    isPluginInstalled(answersPluginId).then(result => {
-        $scope.answersPluginInstalled = result;
-    });
-
-    isPluginInstalled(agentConnectPluginId).then(result => {
-        $scope.agentConnectPluginInstalled = result;
-    });
-
-    isPluginInstalled(agentHubPluginId).then(result => {
-        $scope.agentHubPluginInstalled = result;
-    });
-
-    $scope.agentHubPluginUrl = StateUtils.href.pluginStore() + agentHubPluginId;
-
-    function createWebappModal(componentId, templatePath, webappCategory, loadedWebApp, targetKey, targetValue, defaultName) {
-        $scope.webappCategory = "visual";
-
-        CreateModalFromTemplate(templatePath, $scope, null, function(modalScope) {
-            modalScope.preselectedType = componentId;
-            modalScope.app.name = defaultName;
-            modalScope.app.configFromRole = modalScope.app.configFromRole || {};
-            modalScope.app.configFromRole[targetKey] = targetValue;
-            modalScope.app.config = modalScope.app.config || {};
-            modalScope.app.config[targetKey] = targetValue;
-        }).then(function(webapp) {
-            if (webapp.backendReadyOrNoBackend) {
-                // backend up and running, go directly to view
-                $state.go("projects.project.webapps.webapp.view", {projectKey : $stateParams.projectKey, webAppId: webapp.id, webAppName: $filter('slugify')(webapp.name)});
-            } else {
-                $state.go("projects.project.webapps.webapp.edit", {projectKey : $stateParams.projectKey, webAppId: webapp.id, webAppName: $filter('slugify')(webapp.name)});
-            }
-        });
-    }
-
-    $scope.showCreateAnswersModal = function(webappCategory, loadedWebApp, targetKey, targetValue, defaultName) {
-        createWebappModal(
-            answersComponentId,
-            '/templates/webapps/new-answers-webapp-modal.html',
-            webappCategory,
-            loadedWebApp,
-            targetKey,
-            targetValue,
-            defaultName
-        );
-    };
-
-    $scope.showCreateAgentConnectModal = function(webappCategory, loadedWebApp, targetKey, targetValue, defaultName) {
-        createWebappModal(
-            agentConnectComponentId,
-            '/templates/webapps/new-agent-connect-webapp-modal.html',
-            webappCategory,
-            loadedWebApp,
-            targetKey,
-            targetValue,
-            defaultName
-        );
-    }
-
-    $scope.showCreateAgentHubModal = function(webappCategory, loadedWebApp, targetKey, targetValue, defaultName) {
-        createWebappModal(
-            agentHubComponentId,
-            '/templates/webapps/new-agent-hub-webapp-modal.html',
-            webappCategory,
-            loadedWebApp,
-            targetKey,
-            targetValue,
-            defaultName
-        );
-    }
-
-
-    $scope.sortBy = [
-        { value: 'name', label: 'Name' },
-        { value: '-lastModifiedOn', label: 'Last modified' }
-    ];
-    $scope.selection = $.extend({
-        filterQuery: {
-            userQuery: '',
-            tags: [],
-            interest: {
-                starred: '',
-            },
-        },
-        filterParams: {
-            userQueryTargets: ["name","tags"],
-            propertyRules: {tag: "tags"},
-        },
-        orderQuery: "-lastModifiedOn",
-        orderReversed: false,
-    }, $scope.selection || {});
-
-    $scope.sortCookieKey = 'webapps';
-    $scope.maxItems = 20;
-
-
-    TopNav.setLocation(TopNav.TOP_AGENT_HUB, TopNav.LEFT_AGENT_HUB, TopNav.TABS_NONE, null);
-    TopNav.setNoItem();
-    $scope.list();
-
-    // override because there is no meaningfull sharedState
-    $scope.stopBackendInList = function(webapp) {
-        Dialogs.confirm($scope, 'Stop webapp backend', 'Are you sure you want to stop the backend?').then(function () {
-            WT1.event("webapp-stop", {webAppId: $stateParams.id, type: webapp.type});
-            return DataikuAPI.webapps.stopBackend(webapp)
-                .success(function(){
-                    $scope.list();
-                })
-                .error(setErrorInScope.bind($scope));
-        });
-    };
-});
-
-
-
-
-app.controller("WebAppCoreController", function($scope, $stateParams, $filter, $state, $controller, $timeout, $q, FutureWatcher, WT1, DKUtils, DataikuAPI, TopNav, WebAppsService, Assert, $interval, Notification, WebappContextService) {
+app.controller("WebAppCoreController", function($scope, $stateParams, $filter, $state, $controller, $timeout, $q, FutureWatcher, WT1, DKUtils, DataikuAPI,
+                                                TopNav, WebAppsService, Assert, $interval, Notification, WebappContextService, CodeStudiosService) {
 
     $controller("WebAppsCommonController", {$scope: $scope});
 
@@ -552,6 +399,17 @@ app.controller("WebAppCoreController", function($scope, $stateParams, $filter, $
         })).then(getSummary).then($scope.startUpdatePreview);
     }
 
+    $scope.canEditWebAppInCodeStudio = false;
+    DataikuAPI.codeStudioTemplates.canEditInCodeStudio($stateParams.projectKey).success(function(data) {
+        $scope.canEditWebAppInCodeStudio = data.canEdit;
+    })
+
+    $scope.editWebAppInCodeStudio = function() {
+        $scope.saveWebAppWithCode(null, false).then(function() {
+            CodeStudiosService.editFileInCodeStudio($scope, "webapps",  $stateParams.webAppId);
+        }).catch(setErrorInScope.bind($scope));
+    }
+
     $scope.saveWebAppWithCode = function(commitMessage, forceRestartBackend) {
         WT1.event("webapp-save", {webAppId: $stateParams.id, type: $scope.app.type});
         var deferred = $q.defer();
@@ -566,6 +424,7 @@ app.controller("WebAppCoreController", function($scope, $stateParams, $filter, $
             if (result.backendState == null) {
                 // no backend, just update preview
                 $scope.$broadcast("previewDataUpdated");
+                deferred.resolve();
             } else {
                 $scope.handleStartFuture(result.backendState, deferred);
             }
@@ -711,7 +570,24 @@ app.controller("NewWebAppModalController", function($scope, $rootScope, $window,
             }
             return 0;
         }
-        $scope.codeWebApps = descriptors.filter(d => !d.baseType).sort(f).reverse();
+
+        // tweak the order to have
+        // 1. Standard
+        // 2. Shiny (R)
+        // 3... other web app types (Python) in alphabetical order
+        let codeWebAppDescriptions = [];
+        if (webAppTypes["STANDARD"]) {
+            codeWebAppDescriptions.push(webAppTypes["STANDARD"]);
+        }
+        if (webAppTypes["SHINY"]) {
+            codeWebAppDescriptions.push(webAppTypes["SHINY"]);
+        }
+        codeWebAppDescriptions = codeWebAppDescriptions.concat(descriptors
+            .filter(d => !d.baseType)
+            .filter(d => !["SHINY", "STANDARD"].includes(d.id))
+            .sort(f));
+        $scope.codeWebApps = codeWebAppDescriptions;
+
         $scope.visualWebApps = descriptors.filter(d => d.baseType && (d.roles == null || d.roles.length == 0)).sort(f);
 
         if ($scope.webappCategory === 'visual' && (!$scope.app || !$scope.app.type) && $scope.visualWebApps.length > 0) {
@@ -768,6 +644,8 @@ app.controller("NewWebAppModalController", function($scope, $rootScope, $window,
             $controller("DashWebAppController", {$scope: $scope});
         } else if (type == 'SHINY') {
             $controller("ShinyWebAppController", {$scope: $scope});
+        } else if (type == 'STREAMLIT') {
+            $controller("StreamlitWebAppController", {$scope: $scope});
         } else if (type == 'CODE_STUDIO_AS_WEBAPP') {
             $controller("CodeStudioWebAppController", {$scope: $scope});
         }
