@@ -743,6 +743,46 @@ class GluonTSTransformerHyperparametersSpace(HyperparametersSpace):
         raise NotImplementedError("GluonTS Transformer does not support Bayesian optimization")
 
 
+class CrostonHyperparametersSpace(HyperparametersSpace):
+
+    def build_space(self, strategy):
+        if strategy == "GRID":
+            return self.build_grid()
+        else:
+            return super(CrostonHyperparametersSpace, self).build_space(strategy)
+
+    def build_grid(self):
+        grids = []
+
+        if self.space_definition["variant"].dimension_definition["values"]["TSB"]["enabled"]:
+            grids.append({
+                "alpha_d": self.space_definition["alpha_d"].build("GRID"),
+                "alpha_p": self.space_definition["alpha_p"].build("GRID"),
+                "variant": ["TSB"]
+            })
+
+        variants_except_tsb = copy.deepcopy(self.space_definition["variant"])
+        variants_except_tsb.dimension_definition["values"]["TSB"]["enabled"] = False
+
+        grids.append({
+            "variant": variants_except_tsb.build("GRID")
+        })
+
+        return grids
+
+    @staticmethod
+    def enrich_hyperparam_point(point):
+        variant = point.get("variant", None)
+        if variant != 'TSB':
+            if "alpha_d" in point:
+                del point["alpha_d"]
+            if "alpha_p" in point:
+                del point["alpha_p"]
+        return point
+
+    def get_optimizer(self):
+        raise NotImplementedError("Croston does not support Bayesian optimization")
+
 class TrainableModel(object):
 
     def __init__(self, estimator, hyperparameters_space=None,
@@ -1027,6 +1067,7 @@ GRID_NAMES = {
     "SEASONAL_NAIVE": "seasonal_naive_timeseries_grid",
     "AUTO_ARIMA": "autoarima_timeseries_grid",
     "ARIMA": "arima_grid",
+    "CROSTON": "croston_timeseries_grid",
     "ETS": "ets_timeseries_grid",
     "SEASONAL_LOESS": "seasonal_loess_timeseries_grid",
     "PROPHET": "prophet_timeseries_grid",
